<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'BL' => 'St Barthélemy',
  'KN' => 'St Kitts & Nevis',
  'LC' => 'St Lucia',
  'MF' => 'St Martin',
  'PM' => 'St Pierre & Miquelon',
  'SH' => 'St Helena',
  'UM' => 'US Outlying Islands',
  'VC' => 'St Vincent & the Grenadines',
  'VI' => 'US Virgin Islands',
);
