<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'user_unauthenticated' => 'Webauthn kimlik doğrulaması yapmadan önce giriş yapmanız gerekmektedir',
    'auth_data_not_found' => 'Kimlik doğrulama verileri bulunamadı',
    'create_data_not_found' => 'Kayıt verisi bulunamadı',
    'object_not_found' => 'Nesne bulunamadı',

];
