<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    // contact creation
    'contact_log_contact_created' => 'Created the contact.',
    'settings_log_contact_created_with_name' => 'Added :name as a contact.',

    // contat description update
    'contact_log_contact_description_updated' => 'Updated the description.',
    'settings_log_contact_description_updated_with_name' => 'Updated the description of :name.',

    // contact description clear
    'contact_log_contact_description_cleared' => 'Cleared the description.',
    'settings_log_contact_description_cleared_with_name' => 'Cleared the description of :name.',

    // contact work information update
    'contact_log_contact_work_updated' => 'Updated work information.',
    'settings_log_contact_work_updated_with_name' => 'Updated work information of :name.',

    // company created
    'settings_log_company_created' => 'Created a company called :name.',
];
