<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  689404 => 'Îles du Vent(IDV)',
  689405 => 'Îles du Vent(IDV)',
  689406 => 'Îles Sous-le-vent(ISLV)',
  689408 => 'Îles du Vent(IDV)',
  6894088 => 'Polynesia',
  689409 => 'Remote Archipelago',
  689494 => 'Polynesia',
  689495 => 'Polynesia',
  689496 => 'Polynesia',
  689498 => 'Polynesia',
);
